@@ -6,7 +6,34 @@
 #' 
 #' @param opal Opal object.
 #' @param symbol Name of the R symbol.
-#' @param value Fully qualified name of a variable or a table in Opal or a R expression with allowed assign functions calls.
+#' @param value R expression with allowed assign functions calls.
+#' @param async Whether the call should be asynchronous.
+#' 
+#' @return The R command ID if the async flag is TRUE and if the wait flag is FALSE and if Opal version is at least 2.1, NULL otherwise.
+#' @keywords internal
+.datashield.assign.expr <- function(opal, symbol, value, async=TRUE) {
+  if(is.language(value) || is.function(value)) {
+    contentType <- "application/x-rscript"
+    body <- .deparse(value)
+  } else if(is.character(value)) {
+    contentType <- "application/x-rscript"
+    body <- value
+  } else {
+    stop("Invalid value type: '", class(value), "'. Use quote() to protect from early evaluation.")
+  }
+  query <- list()
+  query["async"] <- ifelse(async, "true", "false")
+  opalr::opal.put(opal, "datashield", "session", opal$rid, "symbol", symbol, query=query, body=body, contentType=contentType)
+}
+
+#' Table data assignment
+#' 
+#' Assign a Opal value to a R symbol in the current Datashield session.
+#' This operation is asynchronous and non blocking.
+#' 
+#' @param opal Opal object.
+#' @param symbol Name of the R symbol.
+#' @param value Fully qualified name of a variable or a table in Opal.
 #' @param variables List of variable names or Javascript expression that selects the variables of a table (ignored if value does not refere to a table). See javascript documentation: http://wiki.obiba.org/display/OPALDOC/Variable+Methods
 #' @param missings If TRUE, missing values will be pushed from Opal to R, default is FALSE. Ignored if value is an R expression.
 #' @param identifiers Name of the identifiers mapping to use when assigning entities to R (from Opal 2.0).
@@ -17,12 +44,8 @@
 #' 
 #' @return The R command ID if the async flag is TRUE and if the wait flag is FALSE and if Opal version is at least 2.1, NULL otherwise.
 #' @keywords internal
-.datashield.assign <- function(opal, symbol, value, variables=NULL, missings=FALSE, identifiers=NULL, id.name=NULL, tibble=FALSE, async=TRUE) {
-  if(is.language(value) || is.function(value)) {
-    contentType <- "application/x-rscript"
-    body <- .deparse(value)
-    query <- list()
-  } else if(is.character(value)) {
+.datashield.assign.table <- function(opal, symbol, value, variables=NULL, missings=FALSE, identifiers=NULL, id.name=NULL, tibble=FALSE, async=TRUE) {
+  if(is.character(value)) {
     contentType <- "application/x-opal"
     body <- value
     variableFilter <- NULL
@@ -65,8 +88,7 @@
   opalr::opal.put(opal, "datashield", "session", opal$rid, "symbol", symbol, query=query, body=body, contentType=contentType)
 }
 
-
-#' Data assignment
+#' Resource data assignment
 #' 
 #' Assign a Opal value to a R symbol in the current Datashield session.
 #' This operation is asynchronous and non blocking.
